==> igniteui-react-layouts-18.3.0-beta.2.tgz: package/esm5/lib/igr-tool-action-separator.js <==
import { __extends } from "tslib";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionSeparator } from "./ToolActionSeparator";
import { ensureBool } from "igniteui-react-core";
var IgrToolActionSeparator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionSeparator, _super);
    function IgrToolActionSeparator(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionSeparator.prototype.createImplementation = function () {
        return new ToolActionSeparator();
    };
    Object.defineProperty(IgrToolActionSeparator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionSeparator.prototype, "size", {
        /**
         * Gets or sets the size of the separator.
        */
        get: function () {
            return this.i.e6;
        },
        set: function (v) {
            this.i.e6 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionSeparator.prototype, "isGroupHeaderSeparator", {
        /**
         * Gets or sets whether to use group header styling or regular styling on this separator.
        */
        get: function () {
            return this.i.e4;
        },
        set: function (v) {
            this.i.e4 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgrToolActionSeparator.prototype.fromInfo = function (info) {
        this.i.dq(info);
    };
    return IgrToolActionSeparator;
}(IgrToolAction));
export { IgrToolActionSeparator };

==> igniteui-react-layouts-18.7.5-beta.2.tgz: package/esm5/lib/igr-tool-action-separator.js <==
import { __extends } from "tslib";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionSeparator } from "./ToolActionSeparator";
import { ensureBool } from "igniteui-react-core";
var IgrToolActionSeparator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionSeparator, _super);
    function IgrToolActionSeparator(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionSeparator.prototype.createImplementation = function () {
        return new ToolActionSeparator();
    };
    Object.defineProperty(IgrToolActionSeparator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionSeparator.prototype, "size", {
        /**
         * Gets or sets the size of the separator.
        */
        get: function () {
            return this.i.g7;
        },
        set: function (v) {
            this.i.g7 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionSeparator.prototype, "isGroupHeaderSeparator", {
        /**
         * Gets or sets whether to use group header styling or regular styling on this separator.
        */
        get: function () {
            return this.i.g5;
        },
        set: function (v) {
            this.i.g5 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionSeparator;
}(IgrToolAction));
export { IgrToolActionSeparator };
